@@ -1,14 +1,14 @@
-descendent.sets <- function(node, s, G.s.obs, to) {
+descendent.sets <- function(node, s, G.s.obs, topo) {
   n.s <- length(s)
   roots <- vapply(s, function(x) {
-    pa <- parents(x, G.s.obs, to)
+    pa <- parents(x, G.s.obs, topo)
     if (length(pa) == 1) return(TRUE)
     return(FALSE)
   }, logical(1))
   n.roots <- sum(roots)
   if (n.roots == 0) return(list())
   desc <- lapply(which(roots), function(i) {
-    de <- descendants(s[i], G.s.obs, to)
+    de <- descendants(s[i], G.s.obs, topo)
     if (node %in% de) return(NULL)
     return(de)
   })
