@@ -1,11 +1,11 @@
-parse.expression <- function(P, to, G.adj, G, G.obs) {
+parse.expression <- function(P, topo, G.adj, G, G.obs) {
   if (P$fraction) {
-    P$num <- parse.expression(P$num, to, G.adj, G, G.obs)
-    P$den <- parse.expression(P$den, to, G.adj, G, G.obs)
+    P$num <- parse.expression(P$num, topo, G.adj, G, G.obs)
+    P$den <- parse.expression(P$den, topo, G.adj, G, G.obs)
     if (is.null(P$den)) {
       sum.P <- P$sumset
       P <- P$num
-      P$sumset <- union(sum.P, P$sumset) %ts% to
+      P$sumset <- union(sum.P, P$sumset) %ts% topo
     }
     return(P)
   }
@@ -13,7 +13,7 @@ parse.expression <- function(P, to, G.adj, G, G.obs) {
     parse.children <- sapply(P$children, FUN = function(x) (x$product | length(x$sumset) > 0 | x$fraction | x$sum))
     if (sum(parse.children) > 0) {
       for (i in which(parse.children)) {
-        P$children[[i]] <- parse.expression(P$children[[i]], to, G.adj, G, G.obs)
+        P$children[[i]] <- parse.expression(P$children[[i]], topo, G.adj, G, G.obs)
       }
     }
     if (length(P$children) > 0) {
@@ -26,11 +26,11 @@ parse.expression <- function(P, to, G.adj, G, G.obs) {
     if (P$sumset == P$var) return (NULL)
     else return (P)
   }
-  ord.children <- order(unlist(lapply(P$children, FUN = function(x) which(to == x$var))), decreasing = TRUE)
-  ord.sum <- order(sapply(P$sumset, FUN = function(x) which(to == x)), decreasing = TRUE)
+  ord.children <- order(unlist(lapply(P$children, FUN = function(x) which(topo == x$var))), decreasing = TRUE)
+  ord.sum <- order(sapply(P$sumset, FUN = function(x) which(topo == x)), decreasing = TRUE)
   P$children <- P$children[ord.children]
   P$sumset <- P$sumset[ord.sum]
-  P <- simplify(P, to, G.adj, G, G.obs)
+  P <- simplify(P, topo, G.adj, G, G.obs)
   if (length(P$children) == 0) return (NULL)
   P.parse <- probability(product = TRUE, children = list())
   remove <- c()
